============================
 sphinxcontrib.spelling 2.0
============================

.. tags:: python sphinx sphinxcontrib-spelling release 

What is sphinxcontrib.spelling?
===============================

`sphinxcontrib.spelling`_ is a spelling checker for Sphinx_.  It uses
PyEnchant_ to produce a report showing misspelled words.

What's New in This Release?
===========================

- Add python 3.3 support.
- Add PyPy support.
- Use pbr for packaging.
- Update tox config to work with forked version of PyEnchant until
  changes are accepted upstream.
